@@ -17,7 +17,6 @@ import uuid
 import warnings
 
 from datetime import datetime
-from pprint import pformat
 from types import FunctionType
 
 if sys.version_info >= (3, 2):
@@ -60,6 +59,13 @@ SDK_VALUE = {
 Raven = None
 
 
+def get_excepthook_client():
+    hook = sys.excepthook
+    client = getattr(hook, 'raven_client', None)
+    if client is not None:
+        return client
+
+
 class ModuleProxyCache(dict):
     def __missing__(self, key):
         module, class_name = key.rsplit('.', 1)
@@ -181,6 +187,8 @@ class Client(object):
         self.environment = o.get('environment') or None
         self.release = o.get('release') or os.environ.get('HEROKU_SLUG_COMMIT')
 
+        self.ignore_exceptions = set(o.get('ignore_exceptions') or ())
+
         self.module_cache = ModuleProxyCache()
 
         if not self.is_enabled():
@@ -236,8 +244,9 @@ class Client(object):
             __excepthook__ = sys.excepthook
 
         def handle_exception(*exc_info):
-            self.captureException(exc_info=exc_info)
+            self.captureException(exc_info=exc_info, level='fatal')
             __excepthook__(*exc_info)
+        handle_exception.raven_client = self
         sys.excepthook = handle_exception
 
     def install_logging_hook(self):
@@ -628,9 +637,10 @@ class Client(object):
                 type(exc).__name__, exc.message)
         else:
             self.error_logger.error(
-                'Sentry responded with an error: %s (url: %s)\n%s',
-                exc, url, pformat(data),
-                exc_info=True
+                'Sentry responded with an error: %s (url: %s)',
+                exc, url,
+                exc_info=True,
+                extra={'data': data}
             )
 
         self._log_failed_submission(data)
@@ -764,9 +774,29 @@ class Client(object):
         """
         if exc_info is None or exc_info is True:
             exc_info = sys.exc_info()
+
+        if not self.should_capture(exc_info):
+            self.logger.info(
+                'Not capturing exception due to filters: %s', exc_info[0],
+                exc_info=sys.exc_info())
+            return
+
         return self.capture(
             'raven.events.Exception', exc_info=exc_info, **kwargs)
 
+    def should_capture(self, exc_info):
+        exc_type = exc_info[0]
+        exc_name = '%s.%s' % (exc_type.__module__, exc_type.__name__)
+        exclusions = self.ignore_exceptions
+
+        if exc_type.__name__ in exclusions:
+            return False
+        elif exc_name in exclusions:
+            return False
+        elif any(exc_name.startswith(e[:-1]) for e in exclusions if e.endswith('*')):
+            return False
+        return True
+
     def capture_exceptions(self, function_or_exceptions=None, **kwargs):
         """
         Wrap a function or code block in try/except and automatically call
