@@ -11,18 +11,15 @@ Acts as an implicit hook for Django installs.
 
 from __future__ import absolute_import, unicode_literals
 
-import copy
 import logging
 import sys
 import warnings
 
 from django.conf import settings
-from hashlib import md5
 
 from raven._compat import PY2, binary_type, text_type, string_types
+from raven.utils.conf import convert_options
 from raven.utils.imports import import_string
-from raven.contrib.django.management import patch_cli_runner
-
 
 logger = logging.getLogger('sentry.errors.client')
 
@@ -121,27 +118,12 @@ def get_client(client=None, reset=False):
         client = getattr(settings, 'SENTRY_CLIENT', 'raven.contrib.django.DjangoClient')
 
     if _client[0] != client or reset:
-        ga = lambda x, d=None: getattr(settings, 'SENTRY_%s' % x, d)
-        options = copy.deepcopy(getattr(settings, 'RAVEN_CONFIG', {}))
-        options.setdefault('include_paths', ga('INCLUDE_PATHS', []))
-        if not options['include_paths']:
-            options['include_paths'] = get_installed_apps()
-        options.setdefault('exclude_paths', ga('EXCLUDE_PATHS'))
-        options.setdefault('timeout', ga('TIMEOUT'))
-        options.setdefault('name', ga('NAME'))
-        options.setdefault('auto_log_stacks', ga('AUTO_LOG_STACKS'))
-        options.setdefault('string_max_length', ga('MAX_LENGTH_STRING'))
-        options.setdefault('list_max_length', ga('MAX_LENGTH_LIST'))
-        options.setdefault('site', ga('SITE'))
-        options.setdefault('processors', ga('PROCESSORS'))
-        options.setdefault('dsn', ga('DSN'))
-        options.setdefault('context', ga('CONTEXT'))
-        options.setdefault('release', ga('RELEASE'))
-
-        transport = ga('TRANSPORT') or options.get('transport')
-        if isinstance(transport, string_types):
-            transport = import_string(transport)
-        options['transport'] = transport
+        options = convert_options(
+            settings,
+            defaults={
+                'include_paths': get_installed_apps(),
+            },
+        )
 
         try:
             Client = import_string(client)
@@ -160,17 +142,6 @@ def get_client(client=None, reset=False):
 
 
 def sentry_exception_handler(request=None, **kwargs):
-    exc_type = sys.exc_info()[0]
-
-    exclusions = set(get_option('IGNORE_EXCEPTIONS', ()))
-
-    exc_name = '%s.%s' % (exc_type.__module__, exc_type.__name__)
-    if exc_type.__name__ in exclusions or exc_name in exclusions or any(exc_name.startswith(e[:-1]) for e in exclusions if e.endswith('*')):
-        logger.info(
-            'Not capturing exception due to filters: %s', exc_type,
-            exc_info=sys.exc_info())
-        return
-
     try:
         client.captureException(exc_info=sys.exc_info(), request=request)
     except Exception as exc:
@@ -243,5 +214,3 @@ if ('raven.contrib.django' in settings.INSTALLED_APPS
         or 'raven.contrib.django.raven_compat' in settings.INSTALLED_APPS):
     register_handlers()
     register_serializers()
-
-    patch_cli_runner()
